@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Грешен Израз</translation>
     </message>
 </context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Калкулатор</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin Калкулатор е прост и лесен десктоп калкулатор. Поддържа събиране, изваждане, умножение и деление.</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Калкулатор</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>Тъмна тема</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Опростен режим</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Научен режим</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>Грешен Израз</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
