@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>ত্রুটিপূর্ণ সমীকরণ</translation>
-    </message>
-</context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>ডিপিন ক্যালকুলেটর</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>ডিপিন ক্যালকুলেটর একটি সাধারণ সহজে ব্যবহার যোগ্য ডেস্কটপ ক্যালকুলেটর। এটা যোগ, বিয়োগ, গুণ এবং ভাগ করতে পারে।</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>ডিপিন ক্যালকুলেটর</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>কালো থীম</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
