@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Fejl i udtryk</translation>
     </message>
 </context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin lommeregner</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin lommeregner er en simpel og let anvendelig skrivebordslommeregner. Den understøtter addition, subtraktion, multiplikation og division.</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin lommeregner</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>Mørkt tema</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Simpel tilstand</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Videnskabelig tilstand</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>Fejl i udtryk</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
