@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>Formule erronée </translation>
-    </message>
-</context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Calculatrice Deepin</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Calculatrice Deepin est une calculatrice de bureau simple et facile à utiliser. Elle prend en charge les additions, les soustractions, les multiplications et les divisions.</translation>
+        <translation>Erreur d&apos;expression</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Calculatrice Deepin</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>Thème sombre</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Mode simple</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Mode scientifique</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>Erreur d&apos;expression</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
