@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>Erro de Expressão</translation>
-    </message>
-</context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Calculator</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>A Deepin Calculator é uma calculadora de ambiente de trabalho simples. Suporta soma, subtração, multiplicação e divisão.</translation>
+        <translation>Erro de expressão</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Calculator</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>Tema Escuro</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Modo simples</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Modo científico</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>Erro de Expressão</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
