@@ -1,31 +1,39 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
 <context>
-    <name>ExpressionList</name>
+    <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
         <translation>Chyba výrazu</translation>
     </message>
 </context>
-<context>
-    <name>Main</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Kalkulačka</translation>
-    </message>
-    <message>
-        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin Kalkulačka je jednoduchá a ľahko použiteľná desktopová kalkulačka. Podporuje sčítanie, odčítanie, násobenie a delenie.</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
-    <message>
-        <source>Deepin Calculator</source>
-        <translation>Deepin Kalkulačka</translation>
-    </message>
     <message>
         <source>Dark Theme</source>
         <translation>Tmavá téma</translation>
     </message>
+    <message>
+        <source>Simple mode</source>
+        <translation>Jednoduchý režim</translation>
+    </message>
+    <message>
+        <source>Scientific mode</source>
+        <translation>Vedecký režim</translation>
+    </message>
+    <message>
+        <source>Deepin Calculator</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>SimpleListDelegate</name>
+    <message>
+        <source>Expression Error</source>
+        <translation>Chyba výrazu</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
